"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/* eslint-disable import/prefer-default-export */
/* eslint-disable no-console */
var chalk_1 = tslib_1.__importDefault(require("chalk"));
var ora_1 = tslib_1.__importDefault(require("ora"));
var enquirer_1 = require("enquirer");
var ts_lib_scripts_utils_1 = require("ts-lib-scripts-utils");
var validatePackageName_1 = require("./validatePackageName");
var getOptions_1 = require("./getOptions");
var genProject_1 = require("./genProject");
var getInstallCmd_1 = tslib_1.__importDefault(require("./getInstallCmd"));
var messages_1 = require("./messages");
var constants_1 = require("./constants");
var paths_1 = require("../config/paths");
var getInstallDepsCmd_1 = tslib_1.__importDefault(require("./getInstallDepsCmd"));
var isCmdInstalled_1 = tslib_1.__importDefault(require("./isCmdInstalled"));
var createGitRepository_1 = tslib_1.__importDefault(require("./createGitRepository"));
var gitCommit_1 = tslib_1.__importDefault(require("./gitCommit"));
var execa = require("execa");
/**
 * 创建项目
 *
 * @param projectName 项目名称
 * @param program 命令行对象
 */
function create(projectName, program) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var packageName, options, spinner, error_1, projectPath, gitCreated, error_2, openWithCode;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    packageName = (program.packageName || projectName);
                    if (!validatePackageName_1.validatePackageName(packageName)) {
                        process.exit(1);
                    }
                    return [4 /*yield*/, getOptions_1.getOptions(projectName, packageName, program)];
                case 1:
                    options = _a.sent();
                    spinner = ora_1.default().start();
                    spinner.start('正在生成项目...');
                    _a.label = 2;
                case 2:
                    _a.trys.push([2, 4, , 5]);
                    return [4 /*yield*/, genProject_1.genProject(options)];
                case 3:
                    _a.sent();
                    spinner.succeed("\u5DF2\u751F\u6210\u9879\u76EE " + chalk_1.default.green(packageName));
                    return [3 /*break*/, 5];
                case 4:
                    error_1 = _a.sent();
                    spinner.fail('生成项目失败');
                    ts_lib_scripts_utils_1.logError(error_1);
                    process.exit(1);
                    return [3 /*break*/, 5];
                case 5:
                    projectPath = paths_1.resolveRoot(options.projectName);
                    gitCreated = createGitRepository_1.default(projectPath);
                    spinner.start(messages_1.dependenciesMessage(constants_1.dependencies, constants_1.devDependencies));
                    _a.label = 6;
                case 6:
                    _a.trys.push([6, 9, , 10]);
                    return [4 /*yield*/, execa(getInstallDepsCmd_1.default(constants_1.dependencies), {
                            cwd: paths_1.resolveRoot(projectName),
                        })];
                case 7:
                    _a.sent();
                    return [4 /*yield*/, execa(getInstallDepsCmd_1.default(constants_1.devDependencies, true), {
                            cwd: paths_1.resolveRoot(projectName),
                        })];
                case 8:
                    _a.sent();
                    spinner.succeed('安装依赖包');
                    messages_1.successMessage(getInstallCmd_1.default(), projectName);
                    return [3 /*break*/, 10];
                case 9:
                    error_2 = _a.sent();
                    spinner.fail("\u5B89\u88C5\u4F9D\u8D56\u5931\u8D25");
                    messages_1.failureMessage([
                        getInstallDepsCmd_1.default(constants_1.dependencies),
                        getInstallDepsCmd_1.default(constants_1.devDependencies, true),
                    ]);
                    process.exit(1);
                    return [3 /*break*/, 10];
                case 10:
                    if (gitCreated) {
                        try {
                            gitCommit_1.default(projectPath);
                        }
                        catch (error) {
                            // 忽略git提交失败
                        }
                    }
                    if (!isCmdInstalled_1.default('code')) return [3 /*break*/, 13];
                    console.log();
                    return [4 /*yield*/, enquirer_1.prompt({
                            type: 'confirm',
                            name: 'openWithCode',
                            message: '使用vscode打开项目？',
                            initial: 'Y',
                        })];
                case 11:
                    openWithCode = (_a.sent()).openWithCode;
                    if (!openWithCode) return [3 /*break*/, 13];
                    return [4 /*yield*/, execa('code', [projectName])];
                case 12:
                    _a.sent();
                    _a.label = 13;
                case 13:
                    process.exit(0);
                    return [2 /*return*/];
            }
        });
    });
}
exports.default = create;
//# sourceMappingURL=index.js.map